@@ -49,6 +49,8 @@ class KARPClient(object):
                 )
             successful = True
         except Exception as e:
+            if req.response:
+                traceback.print_exc()
             response_data = e.__str__()
             successful = False
         if req.response:
