@@ -115,6 +115,8 @@ class KARPServer:
                 )
             successful = True
         except (Exception, AssertionError) as e:
+            if not req.response:
+                self.logger.warning(traceback.format_exc(e))
             response_data = e.__str__()
             successful = False
         if req.response:
